==> qtjambi-webenginecore-6.4.0-sources.jar: io/qt/webengine/core/QtWebEngineCore.java <==
package io.qt.webengine.core;


/**
 * <p>Java wrapper for Qt header file QtWebEngineCore</p>
 */
public final class QtWebEngineCore
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    private QtWebEngineCore() throws java.lang.InstantiationError { throw new java.lang.InstantiationError("Cannot instantiate namespace QtWebEngineCore."); }
    
    /**
     * <p>Java wrapper for Qt enum QtWebEngineCore::ReferrerPolicy</p>
     */
    @io.qt.QtRejectedEntries({"Last"})
    public enum ReferrerPolicy implements io.qt.QtEnumerator {
        Always(0),
        Default(1),
        NoReferrerWhenDowngrade(2),
        Never(3),
        Origin(4),
        OriginWhenCrossOrigin(5),
        NoReferrerWhenDowngradeOriginWhenCrossOrigin(6),
        SameOrigin(7),
        StrictOrigin(8),
        Last(8);

        private ReferrerPolicy(int value) {
            this.value = value;
        }

        /**
         * {@inheritDoc}
         */
        public int value() {
            return value;
        }

        /**
         * Returns the corresponding enum entry for the given value.
         * @param value
         * @return enum entry
         */
        public static ReferrerPolicy resolve(int value) {
            switch (value) {
            case 0: return Always;
            case 1: return Default;
            case 2: return NoReferrerWhenDowngrade;
            case 3: return Never;
            case 4: return Origin;
            case 5: return OriginWhenCrossOrigin;
            case 6: return NoReferrerWhenDowngradeOriginWhenCrossOrigin;
            case 7: return SameOrigin;
            case 8: return StrictOrigin;
            default: throw new io.qt.QNoSuchEnumValueException(value);
            }
        }


        private final int value;
    }
    
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qtwebenginecoreglobal-h.html#qWebEngineChromiumSecurityPatchVersion">qWebEngineChromiumSecurityPatchVersion()</a></p>
     */
    public native static java.lang.String qWebEngineChromiumSecurityPatchVersion();
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qtwebenginecoreglobal-h.html#qWebEngineChromiumVersion">qWebEngineChromiumVersion()</a></p>
     */
    public native static java.lang.String qWebEngineChromiumVersion();
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qtwebenginecoreglobal-h.html#qWebEngineVersion">qWebEngineVersion()</a></p>
     */
    public native static java.lang.String qWebEngineVersion();
    
}

==> qtjambi-webenginecore-6.4.4-sources.jar: io/qt/webengine/core/QtWebEngineCore.java <==
package io.qt.webengine.core;

import io.qt.*;


/**
 * <p>Java wrapper for Qt header file QtWebEngineCore</p>
 */
public final class QtWebEngineCore
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    private QtWebEngineCore() throws java.lang.InstantiationError { throw new java.lang.InstantiationError("Cannot instantiate namespace QtWebEngineCore."); }
    
    /**
     * <p>Java wrapper for Qt enum QtWebEngineCore::ReferrerPolicy</p>
     */
    @QtRejectedEntries({"Last"})
    public enum ReferrerPolicy implements QtEnumerator {
        Always(0),
        Default(1),
        NoReferrerWhenDowngrade(2),
        Never(3),
        Origin(4),
        OriginWhenCrossOrigin(5),
        NoReferrerWhenDowngradeOriginWhenCrossOrigin(6),
        SameOrigin(7),
        StrictOrigin(8),
        Last(8);

        static {
            QtJambi_LibraryUtilities.initialize();
        }

        private ReferrerPolicy(int value) {
            this.value = value;
        }

        /**
         * {@inheritDoc}
         */
        public int value() {
            return value;
        }

        /**
         * Returns the corresponding enum entry for the given value.
         * @param value
         * @return enum entry
         */
        public static ReferrerPolicy resolve(int value) {
            switch (value) {
            case 0: return Always;
            case 1: return Default;
            case 2: return NoReferrerWhenDowngrade;
            case 3: return Never;
            case 4: return Origin;
            case 5: return OriginWhenCrossOrigin;
            case 6: return NoReferrerWhenDowngradeOriginWhenCrossOrigin;
            case 7: return SameOrigin;
            case 8: return StrictOrigin;
            default: throw new QNoSuchEnumValueException(value);
            }
        }


        private final int value;
    }
    
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qtwebenginecoreglobal-h.html#qWebEngineChromiumSecurityPatchVersion">qWebEngineChromiumSecurityPatchVersion()</a></p>
     */
    public native static java.lang.@Nullable String qWebEngineChromiumSecurityPatchVersion();
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qtwebenginecoreglobal-h.html#qWebEngineChromiumVersion">qWebEngineChromiumVersion()</a></p>
     */
    public native static java.lang.@Nullable String qWebEngineChromiumVersion();
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qtwebenginecoreglobal-h.html#qWebEngineVersion">qWebEngineVersion()</a></p>
     */
    public native static java.lang.@Nullable String qWebEngineVersion();
    
}
